"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpResponse_1 = __importDefault(require("../responses/HttpResponse"));
class HttpError extends Error {
    constructor(statusCode = 500, message = 'InternalServerError', extra) {
        super(message);
        this._statusCode = statusCode;
        this._extra = extra;
        this._body = JSON.stringify({ message, extra });
    }
    static buildError(error) {
        if (error instanceof HttpError) {
            return new HttpResponse_1.default(error.statusCode, error.body);
        }
        return new HttpResponse_1.default(500, { message: error.message, stack: error.stack });
    }
    get statusCode() {
        return this._statusCode;
    }
    get body() {
        return this._body;
    }
    get extra() {
        return this._extra;
    }
    getResponse() {
        return {
            statusCode: this._statusCode,
            body: this._body,
            headers: HttpResponse_1.default.defaultHeaders,
        };
    }
}
exports.default = HttpError;
//# sourceMappingURL=HttpError.js.map