"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HeadersFixer_1 = __importDefault(require("../proxy/HeadersFixer"));
class HttpResponse {
    constructor(statusCode = 200, body = undefined, headers = HttpResponse.defaultHeaders) {
        this._statusCode = statusCode;
        this._body = typeof body === 'string' ? body : JSON.stringify(body);
        this._headers = Object.assign(Object.assign({}, headers), HttpResponse.mandatoryHeaders);
    }
    static expandMandatoryHeaders(headers) {
        HttpResponse.mandatoryHeaders = Object.assign(Object.assign({}, HttpResponse.mandatoryHeaders), headers);
    }
    static expandDefaultHeaders(headers) {
        HttpResponse.defaultHeaders = Object.assign(Object.assign({}, HttpResponse.defaultHeaders), headers);
    }
    static buildResponse(res) {
        if (res instanceof HttpResponse) {
            return res.getResponse();
        }
        return res;
    }
    get statusCode() {
        return this._statusCode;
    }
    get body() {
        return this._body;
    }
    get headers() {
        return this._headers;
    }
    getResponse() {
        return {
            statusCode: this._statusCode,
            body: this._body,
            headers: Object
                .entries(this._headers)
                .reduce((acc, [k, v]) => (Object.assign(Object.assign({}, acc), { [HeadersFixer_1.default.uppercaseHeader(k)]: v })), {}),
        };
    }
}
exports.default = HttpResponse;
HttpResponse.defaultHeaders = {
    'Content-Type': 'application/json',
};
HttpResponse.mandatoryHeaders = {};
//# sourceMappingURL=HttpResponse.js.map